@@ -18,8 +18,6 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
 
-import org.slf4j.spi.MDCAdapter;
-
 /**
  * A <em>Mapped Diagnostic Context</em>, or MDC in short, is an instrument for
  * distinguishing interleaved log output from different sources. Log output is
@@ -95,6 +93,7 @@ public class DuplicateOnInsertLogbackMDCAdapter extends LogbackMDCAdapter {
      *
      * @throws IllegalArgumentException in case the "key" parameter is null
      */
+    @Override
     public void put(String key, String val) throws IllegalArgumentException {
         if (key == null) {
             throw new IllegalArgumentException("key cannot be null");
@@ -115,13 +114,15 @@ public class DuplicateOnInsertLogbackMDCAdapter extends LogbackMDCAdapter {
      * Remove the the context identified by the <code>key</code> parameter.
      * <p/>
      */
+    @Override
     public void remove(String key) {
         if (key == null) {
             return;
         }
         Map<String, String> oldMap = copyOnThreadLocal.get();
-        if (oldMap == null)
+        if (oldMap == null) {
             return;
+        }
 
         Integer lastOp = getAndSetLastOperation(WRITE_OPERATION);
 
@@ -136,6 +137,7 @@ public class DuplicateOnInsertLogbackMDCAdapter extends LogbackMDCAdapter {
     /**
      * Clear all entries in the MDC.
      */
+    @Override
     public void clear() {
         lastOperation.set(WRITE_OPERATION);
         copyOnThreadLocal.remove();
@@ -145,6 +147,7 @@ public class DuplicateOnInsertLogbackMDCAdapter extends LogbackMDCAdapter {
      * Get the context identified by the <code>key</code> parameter.
      * <p/>
      */
+    @Override
     public String get(String key) {
         final Map<String, String> map = copyOnThreadLocal.get();
         if ((map != null) && (key != null)) {
@@ -158,6 +161,7 @@ public class DuplicateOnInsertLogbackMDCAdapter extends LogbackMDCAdapter {
      * Get the current thread's MDC as a map. This method is intended to be used
      * internally.
      */
+    @Override
     public Map<String, String> getPropertyMap() {
         lastOperation.set(MAP_COPY_OPERATION);
         return copyOnThreadLocal.get();
@@ -181,6 +185,7 @@ public class DuplicateOnInsertLogbackMDCAdapter extends LogbackMDCAdapter {
      * Return a copy of the current thread's context map. Returned value may be
      * null.
      */
+    @Override
     public Map<String, String> getCopyOfContextMap() {
         Map<String, String> hashMap = copyOnThreadLocal.get();
         if (hashMap == null) {
@@ -190,6 +195,7 @@ public class DuplicateOnInsertLogbackMDCAdapter extends LogbackMDCAdapter {
         }
     }
 
+    @Override
     public void setContextMap(Map<String, String> contextMap) {
         lastOperation.set(WRITE_OPERATION);
 
@@ -199,4 +205,4 @@ public class DuplicateOnInsertLogbackMDCAdapter extends LogbackMDCAdapter {
         // the newMap replaces the old one for serialisation's sake
         copyOnThreadLocal.set(newMap);
     }
-}
+}
\ No newline at end of file
